import "Turbine.Gameplay.Attributes"
	MaxMorale=Player:GetMaxMorale()
	MaxPower=Player:GetMaxPower()
	
	--Add a callbacks if the players maximum morale/power changes.
	AddCallback(Player, "BaseMaxMoraleChanged", function(sender, args) MaxMorale=Player:GetMaxMorale() LPMUpdate() end)
	AddCallback(Player, "BaseMaxPowerChanged", function(sender, args)	MaxPower=Player:GetMaxPower() LPMUpdate() end)
	
	--Callbacks when Morale or Power changes.
	AddCallback(Player,"MoraleChanged", function(sender, args) LPMUpdate() end)
	AddCallback(Player,"PowerChanged", function(sender, args) LPMUpdate() end)

function LPMUpdate()
		local PowerLevel=Player:GetPower()/MaxPower
		local MoraleLevel=Player:GetMorale()/MaxMorale
		
		for i=1,#Bar do
				if Bar[i].Data.PowerBar~=nil then
					if PowerLevel<Bar[i].Data.PowerBar then Bar[i].LowPower=true Bar[i]:Show() else Bar[i].LowPower=false Bar[i]:Hide() end
				end
				if Bar[i].Data.MoraleBar~=nil then
					if MoraleLevel<Bar[i].Data.MoraleBar then Bar[i].LowMorale=true Bar[i]:Show() else Bar[i].LowMorale=false Bar[i]:Hide() end
				end
		end
end

--Add the "LPM Bar" option to every Bar.
table.insert(Context,
function (self,contextMenu,contextMenuItems)
	local LPMBar = Turbine.UI.MenuItem( "Power/Morale must be...");
		contextMenu.LPMs = LPMBar:GetItems()
		LPMMenu={}
		
		
	for i=0,10 do
		--First add a Morale Option
		local text="Morale below "..(i*10).."%"
		local level=self.Data.MoraleBar or nil
		if type(level)=="number" then val=(level*10>=i) else val=nil end
		LPMMenu[i]= Turbine.UI.MenuItem( text,true, val );
		LPMMenu[i].Click = function( sender, args )
			for j=0,20 do
				LPMMenu[j]:SetChecked(false)
			end
			for j=0,i do
				LPMMenu[j]:SetChecked(true)
			end
			self.Data.MoraleBar=i/10
			self.Data.PowerBar=nil
			LPMUpdate()
		end
		contextMenu.LPMs:Add(LPMMenu[i])
	end
	for i=0,10 do
		--Then add the Power Option
		local text="Power below "..(i*10).."%"
		local level=self.Data.PowerBar or nil
		if type(level)=="number" then val=(level*10>=i) else val=nil end
		LPMMenu[i+11]= Turbine.UI.MenuItem( text,true, val );
		LPMMenu[i+11].Click = function( sender, args )
			for j=0,20 do
				LPMMenu[j]:SetChecked(false)
			end
			for j=11,i do
				LPMMenu[j]:SetChecked(true)
			end
			self.Data.PowerBar=i/10
			self.Data.MoraleBar=nil
			LPMUpdate()
		end
		contextMenu.LPMs:Add(LPMMenu[i+11])
	end
		--Option to clear the setting
	LPMMenu[199] = Turbine.UI.MenuItem( "Clear Morale/Power setting");
	LPMMenu[199].Click = function( sender, args )
			for j=0,20 do
				LPMMenu[j]:SetChecked(false)
			end
		self.Data.PowerBar=nil
		self.Data.MoraleBar=nil
		LPMUpdate()
	end
	contextMenu.LPMs:Add(LPMMenu[199])

	contextMenuItems:Add( LPMBar )
end)

LPMUpdate()

table.insert(Opt.Module,
	function()
	
	Opt.LPM={}
	
	table.insert(Opt.source,"PowerBar")
	table.insert(Opt.source,"MoraleBar")
	--Two dummy controls for this
	Opt.PowerBar=Opt.CheckBox("NOT SHOWN!",function(k,i) end)
	Opt.MoraleBar=Opt.CheckBox("NOT SHOWN!",function(k,i) end)
	
	Opt.LPM.CB=CollapseBox("Low Power/Morale Options","f",1,true)
	
	Opt.ListBox:AddItem(Opt.LPM.CB)
	
	--Radio - Three settings
	Opt.LPM.Radio=Opt.Radio(
		{"None","Morale below","Power below"},
		function(k,i)
			Opt.LPM.Flag=k
			if Opt.LPM.Flag==0 then
				Bar[i].Data.PowerBar=nil
				Bar[i].Data.MoraleBar=nil
				LPMUpdate()
			end
			if k==1 then
				if Bar[i].Data.MoraleBar==nil then
					Bar[i].Data.MoraleBar=0.5
					Bar[i].Data.PowerBar=nil
					LPMUpdate()
				end
			end
			if k==2 then
				if Bar[i].Data.PowerBar==nil then
					Bar[i].Data.MoraleBar=nil
					Bar[i].Data.PowerBar=0.5
					LPMUpdate()
				end
			end
		end)
	Opt.LPM.CB.Content:AddItem(Opt.LPM.Radio)
	
	--Slider; Choose Percentage
	Opt.LPM.S=Opt.Slider("Below",0,100,
		function(k,i) 
			if Opt.LPM.Flag==1 then
				Bar[i].Data.MoraleBar=k/100
				Bar[i].Data.PowerBar=nil
			end
			if Opt.LPM.Flag==2 then
				Bar[i].Data.MoraleBar=nil
				Bar[i].Data.PowerBar=k/100
			end
			LPMUpdate()
		end) 
	Opt.LPM.CB.Content:AddItem(Opt.LPM.S)
	
	end)

table.insert(Opt.Updaters,
	function()
		local p
		if Opt.val.MoraleBar>0 then 
			p=Opt.val.MoraleBar*100
			Opt.LPM.Flag=1 
			Opt.LPM.Radio:SetVal("Morale below")
		elseif Opt.val.PowerBar>0 then 	
			p=Opt.val.PowerBar*100
			Opt.LPM.Flag=2 
			Opt.LPM.Radio:SetVal("Power below") 
		else
			Opt.LPM.Flag=0
			Opt.LPM.Radio:SetVal("None")
		end
		Opt.LPM.S:SetVal(p)
		
		if Opt.Check.MoraleBar or Opt.Check.PowerBar then 
			--Not all the Bars have the same value for this set the back to grey
			Opt.LPM.Radio:SetBackColor(Turbine.UI.Color(1,0.3,0.3,0.3))
			Opt.LPM.S:SetBackColor(Turbine.UI.Color(1,0.3,0.3,0.3))
		else
			--All the same? Transparent back
			Opt.LPM.Radio:SetBackColor(nil)
			Opt.LPM.S:SetBackColor(nil)
		end	
		
		
	end)
